Other commands
**************

Unit-testing
============
.. cmakemodule:: ../../test.cmake
.. cmakemodule:: ../../gtest.cmake

Xacro
=====
.. cmakemodule:: ../../xacro.cmake

IDL
===
.. cmakemodule:: ../../idl.cmake

Version script
==============

.. cmakemodule:: ../../version-script.cmake

Cython
======

.. cmakemodule:: ../../cython/cython.cmake

Make targets
============

The following macros define targets which are added to the Makefile:

- :ref:`dist <target-dist>`: generates a tarball;
- :ref:`distcheck <target-distcheck>`: checks the generated tarball;
- :ref:`release <target-release>`: releases a stable version of the current package.

.. cmakemodule:: ../../dist.cmake
.. cmakemodule:: ../../distcheck.cmake
.. cmakemodule:: ../../release.cmake
